Re: [PATCH] diff-delta: bound hash list length to avoid O(m*n) behavior
- From
Linus Torvalds <torvalds@osdl.org>
- Date
- Mar 4, 2006, 06:21 UTC
- Message-ID
- <Pine.LNX.4.64.0603032217470.22647@g5.osdl.org>
- In-Reply-To
- <7vfylzx7t3.fsf@assigned-by-dhcp.cox.net>
On Fri, 3 Mar 2006, Junio C Hamano wrote:
Show 9 quoted lines
> > The first round. The set of objects packed were from > today's Linus tip (everything down to epoch v2.6.12-rc2), 193309 > objects in total, on my Duron 750 with slow disks. > > real user sys bytes savings > master 11m17.121s 10m23.280s 0m47.290s 109045599 N/A > nico 25m37.058s 23m0.770s 2m20.460s 104401392 4.25% > jc 24m12.072s 21m45.120s 2m16.400s 104409761 4.25%
Ouch.
Btw, it's often worth using /usr/bin/time instead of the bash built-in time. Why? Because /usr/bin/time reports one absolutely _hugely_ important number (maybe more important than almost any of the other numbers in there).
Which one? It's the "minor pagefaults". That's a very good approximation of memory usage overhead.
We've already had one person report that they ran out of memory when packing. So memory usage is actually a problem.
Anyway, it looks like the 16-byte window is the way to go, even regardless of any memory use issue.
Linus